@@ -275,14 +275,6 @@ pub enum GovernanceError {
     /// Governance PDA must sign
     #[error("Governance PDA must sign")]
     GovernancePdaMustSign,
-
-    /// Invalid config realm for Governance
-    #[error("Invalid config realm for Governance")]
-    InvalidConfigRealmForGovernance,
-
-    /// Invalid config governed account for Governance
-    #[error("Invalid config governed account for Governance")]
-    InvalidConfigGovernedAccountForGovernance,
 }
 
 impl PrintProgramError for GovernanceError {
