@@ -4,7 +4,7 @@ use crate::{
     state::{
         enums::GovernanceAccountType,
         governance::{
-            assert_is_valid_governance_config, get_account_governance_address_seeds, Governance,
+            assert_valid_create_governance_args, get_account_governance_address_seeds, Governance,
             GovernanceConfig,
         },
     },
@@ -27,18 +27,21 @@ pub fn process_create_account_governance(
     let account_info_iter = &mut accounts.iter();
 
     let realm_info = next_account_info(account_info_iter)?; // 0
-    let account_governance_info = next_account_info(account_info_iter)?; // 0
-    let payer_info = next_account_info(account_info_iter)?; // 1
-    let system_info = next_account_info(account_info_iter)?; // 2
+    let account_governance_info = next_account_info(account_info_iter)?; // 1
+    let governed_account_info = next_account_info(account_info_iter)?; // 2
+    let payer_info = next_account_info(account_info_iter)?; // 3
+    let system_info = next_account_info(account_info_iter)?; // 4
 
-    let rent_sysvar_info = next_account_info(account_info_iter)?; // 3
+    let rent_sysvar_info = next_account_info(account_info_iter)?; // 5
     let rent = &Rent::from_account_info(rent_sysvar_info)?;
 
-    assert_is_valid_governance_config(program_id, &config, realm_info)?;
+    assert_valid_create_governance_args(program_id, &config, realm_info)?;
 
     let account_governance_data = Governance {
         account_type: GovernanceAccountType::AccountGovernance,
-        config: config.clone(),
+        realm: *realm_info.key,
+        governed_account: *governed_account_info.key,
+        config,
         proposals_count: 0,
         reserved: [0; 8],
     };
@@ -47,7 +50,7 @@ pub fn process_create_account_governance(
         payer_info,
         account_governance_info,
         &account_governance_data,
-        &get_account_governance_address_seeds(&config.realm, &config.governed_account),
+        &get_account_governance_address_seeds(realm_info.key, governed_account_info.key),
         program_id,
         system_info,
         rent,
