@@ -55,7 +55,7 @@ pub fn process_create_proposal(
     let token_owner_record_data = get_token_owner_record_data_for_realm_and_governing_mint(
         program_id,
         token_owner_record_info,
-        &governance_data.config.realm,
+        &governance_data.realm,
         &governing_token_mint,
     )?;
 
